smartcard.Exceptions.NoReadersException

# ``smartcard`.`Exceptions`.`NoReadersException``

exception documentation

`class NoReadersException(SmartcardException):`

View In Hierarchy

Raised when the system has no smartcard reader.

Method | `__init__` | Undocumented

Inherited from `SmartcardException`:

Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self, *args):
overrides `smartcard.Exceptions.SmartcardException.__init__`

Undocumented